Resiland is a testbed that allows one to modify resilience of a multistable networked dynamical system in a controlled manner and to generate time series of observables that may be used to evaluate the suitability of data-driven indicators of resilience. Resiland is a noval ansatz for simulation of a modification of system’s resilience (Resi-) in a potential landscape (-land). Self-induced transitions allow state changes without a change of resilience and distinguishable dynamics allow to simulate real-world systems with different functionings, structures and feedbacks. Furthermore, a change of the potential landscape influence resilience and simulations up to a system crises are possbile.

- Examples: Take a look into the examples to get started and for reference.
- Issue Tracker: Please report any bugs here. Also feel free to ask for new features.
- Installation instructions: In most cases, pip3 install resiland or similar should do the job.
